## 1.0.0 (2024-10-14)


### Features

* add fix code generator ([22f7407](https://github.com/ScrapeGraphAI/scrapontologies/commit/22f74073f54b8ff297e225877caadc041bc4ba07))
* added renderers, fixed temp file and update entities bugs, enhanced prompts ([d86521e](https://github.com/ScrapeGraphAI/scrapontologies/commit/d86521e7f19a1bfd55937fc1c0760a898a14b5d5))
* digestion multiples pdfs ([e61e3ee](https://github.com/ScrapeGraphAI/scrapontologies/commit/e61e3ee21594c30f3e55eaee736966fe019139f5))
* entities and base_parser refactoring, behavior change extract_entities ([eea2a3f](https://github.com/ScrapeGraphAI/scrapontologies/commit/eea2a3f4e4c02d2955fbe62925fc7771d59c633b))
* extraction values of entities single file ([1b59a65](https://github.com/ScrapeGraphAI/scrapontologies/commit/1b59a657d4b642a94ff95bfe011ed392930c7dc7))
* implementd creates tables from json schema ([ce588b5](https://github.com/ScrapeGraphAI/scrapontologies/commit/ce588b59f06519625e3185b329d3c7ed8174bb81))
* implemented db client with postgres integration ([824ceb8](https://github.com/ScrapeGraphAI/scrapontologies/commit/824ceb85015ff221e4d151fbb6f1bd21683ab1c3))
* implemented file_extractor and make a massive refactoring ([1338b4b](https://github.com/ScrapeGraphAI/scrapontologies/commit/1338b4b137fc86015184e4c6089696a8d440d627))
* implemented langraph logic for entities ([6a5db31](https://github.com/ScrapeGraphAI/scrapontologies/commit/6a5db313d3eee74a1c14f4e73d2b73989899bc80))
* implemented langraph logic for relations ([8d5412f](https://github.com/ScrapeGraphAI/scrapontologies/commit/8d5412fde77db78a26ef19ee37ddd4431df60198))
* implemented llm_client ([41286df](https://github.com/ScrapeGraphAI/scrapontologies/commit/41286df944e3a3b7adf3f4790c20fa675a2c0641))
* implemented relationship extraction ([566275c](https://github.com/ScrapeGraphAI/scrapontologies/commit/566275c0cbed3007514d7457713b6c1dbbeb6676))
* merge schemas implementation ([83e9dcf](https://github.com/ScrapeGraphAI/scrapontologies/commit/83e9dcf149846a6dd7cb0f38e1aeea502b9778fb))
* neo4j implementation ([3778bc6](https://github.com/ScrapeGraphAI/scrapontologies/commit/3778bc69e35d1f059ca4c06a3ca7a060af8b19d2))
* prompt based extraction ([dbd9c6e](https://github.com/ScrapeGraphAI/scrapontologies/commit/dbd9c6e399e85950679afd2d641ea94aec4c5a79))
* Removed pdf2image dependency now it's via poppler ([7696253](https://github.com/ScrapeGraphAI/scrapontologies/commit/76962530a684651747bd38e7131532447211d00d))
* updated schema with new documents ([9fa2e32](https://github.com/ScrapeGraphAI/scrapontologies/commit/9fa2e32b7d3b76443ff2a6a8ba0f5fc84fde7c4f))


### Bug Fixes

*  print to logging ([c413ea1](https://github.com/ScrapeGraphAI/scrapontologies/commit/c413ea1430fe0ace7f6fe69aa86004239dcd54f9))
* entities generation ([3da8da3](https://github.com/ScrapeGraphAI/scrapontologies/commit/3da8da3eb7439e2204a56deedeb859aa20102edf))
* example name ([6380e83](https://github.com/ScrapeGraphAI/scrapontologies/commit/6380e835946d6adf64abd1c098e73c11ad3dede7))
* extract entities-relationships schema ([2826d9d](https://github.com/ScrapeGraphAI/scrapontologies/commit/2826d9d93d06416db84155007be87e7e7d4ca2ca))
* fixed all the private field names ([d1f6e08](https://github.com/ScrapeGraphAI/scrapontologies/commit/d1f6e0844dcd6bdb0fdeb3cbe4f32795805ac8df))
* insert id in the Relation class ([9295168](https://github.com/ScrapeGraphAI/scrapontologies/commit/92951686dbecf8ff1d8f839648466bd3dfa33b60))
* release version ([fa955ff](https://github.com/ScrapeGraphAI/scrapontologies/commit/fa955ff487482fea4b3cf6876bd587a9c4484f93))


### Docs

* add docstring to some function in pdf_parser ([bf84d9f](https://github.com/ScrapeGraphAI/scrapontologies/commit/bf84d9fce8b7c5d0fd5c07addd86ee0e82134c60))
* added screenshot ([c50c31c](https://github.com/ScrapeGraphAI/scrapontologies/commit/c50c31c789a90bc1aa549baea9d2f8f01b5bffa0))
* CHANGELOG.md ([698db0d](https://github.com/ScrapeGraphAI/scrapontologies/commit/698db0d184514d5d141ea8a23ae7fd9e6eebc3eb))
* create example folder ([1217a32](https://github.com/ScrapeGraphAI/scrapontologies/commit/1217a32903fdc1cb52b45da7d566fd7a3c8d1d82))
* fix  pyproject.toml ([27e3ee2](https://github.com/ScrapeGraphAI/scrapontologies/commit/27e3ee2484387030ab3c17bbb5959bfaadd70b32))
* fix CHANGELOG.md ([b4ddb2c](https://github.com/ScrapeGraphAI/scrapontologies/commit/b4ddb2cd99b83cf2d1c6b90ca47e0bb1e1c1de68))


### Refactor

* change name lib scrapontologies ([08f85b2](https://github.com/ScrapeGraphAI/scrapontologies/commit/08f85b2abaf7655f4892e9635b74635a9e76263a))
* entities_schema, relations_schema ([cdc463d](https://github.com/ScrapeGraphAI/scrapontologies/commit/cdc463d6e5ee949568a977cfca1e6ceaf8d98899))


### CI

* **release:** 1.0.0 [skip ci] ([851c60d](https://github.com/ScrapeGraphAI/scrapontologies/commit/851c60dfae1f6ee00d1c0488e150e277802f68f8))
* **release:** 1.0.0 [skip ci] ([d864e4e](https://github.com/ScrapeGraphAI/scrapontologies/commit/d864e4e9cfa727ac7f6de3c040cf03730d0274d5))
* **release:** 1.0.0 [skip ci] ([306ceb3](https://github.com/ScrapeGraphAI/scrapontologies/commit/306ceb387322b760b9d223a2c153cbef07830a8e))
* **release:** 1.0.0 [skip ci] ([d7218aa](https://github.com/ScrapeGraphAI/scrapontologies/commit/d7218aa687e8ecbf30accd325330b45c9abe653e))
* **release:** 1.1.0 [skip ci] ([0cb760a](https://github.com/ScrapeGraphAI/scrapontologies/commit/0cb760a2c9e6c5c0771480a5e380fced68d33514))
